@@ -26,7 +26,7 @@ lgreen = '\033[92m'
 clear = '\033[0m'
 bold = '\033[01m'
 cyan = '\033[96m'
-version = "1.2.1"
+version = "1.2.2"
 
 major = str(sys.version_info.major)
 minor = str(sys.version_info.minor)
@@ -266,7 +266,7 @@ class ip:
         message = " ".join([str(m) for m in message])
         client = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
         client.connect((mail_ip, mail_port))
-        client.sendall(bytes("smtp|"+email+"|"+message,'UTF-8'))
+        client.sendall(bytes("smtp|de|"+email+"|"+message,'UTF-8'))
         code = client.recv(4096)
         print(code)
     def telegram(data=False):
